@@ -3,11 +3,10 @@ extern crate prost_build;
 use std::path::PathBuf;
 
 fn main() {
-    println!("cargo:rerun-if-changed=build.rs");
-    println!("cargo:rerun-if-changed=*.proto");
+    let blizzard_proto_path = PathBuf::from("src").join("blizzard").join("proto");
+    println!("cargo:rerun-if-changed={}", blizzard_proto_path.to_string_lossy());
 
     println!("Compiling protos...");
-    let blizzard_proto_path = PathBuf::from("src").join("blizzard").join("proto");
     prost_build::Config::new()
         .out_dir(&blizzard_proto_path)
         .compile_protos(
