@@ -4,31 +4,21 @@ use directories::BaseDirs;
 
 use crate::error::{Error, ErrorKind, Result};
 
+pub fn get_launcher_executable() -> Result<PathBuf> {
+    return get_launcher_path().map(|path| path.join("App").join("Amazon Games.exe"));
+}
+
 pub fn get_launcher_path() -> Result<PathBuf> {
     let launcher_path = BaseDirs::new()
         .map(|base_dirs| PathBuf::from(base_dirs.data_local_dir()))
         .map(|path| path.join("Amazon Games"));
 
-    if launcher_path.is_none() {
-        return Err(Error::new(
+    return launcher_path
+        .filter(|value| value.exists())
+        .ok_or(Error::new(
             ErrorKind::LauncherNotFound,
             "Invalid Amazon Games path, maybe this launcher is not installed",
         ));
-    }
-
-    let launcher_path = launcher_path.unwrap();
-
-    if !launcher_path.exists() {
-        return Err(Error::new(
-            ErrorKind::LauncherNotFound,
-            format!(
-                "Invalid Amazon Games path, maybe this launcher is not installed: {}",
-                launcher_path.display().to_string()
-            ),
-        ));
-    }
-
-    return Ok(launcher_path);
 }
 
 pub fn get_manifests_path(launcher_path: &Path) -> Result<PathBuf> {
