@@ -1,7 +1,9 @@
 use std::path::PathBuf;
 
-use crate::error::{Error, ErrorKind, Result};
-use crate::util::registry;
+use crate::{
+    error::{Error, ErrorKind, Result},
+    utils::registry,
+};
 
 pub fn get_manifests_path() -> PathBuf {
     PathBuf::from("C:\\ProgramData\\Battle.net\\Agent\\product.db")
@@ -18,8 +20,7 @@ pub fn get_launcher_executable() -> Result<PathBuf> {
             ErrorKind::LauncherNotFound,
             "Invalid Blizzard path, maybe this launcher is not installed",
         )
-    })
-    .unwrap();
+    })?;
 
     if !launcher_executable.exists() {
         return Err(Error::new(
